.boxInfoMessError{
    background-color: #ea9999;
}

.boxInfoMessOK{
    background-color: #f3f0ac;
}
.textHead{
    text-shadow: 2px 2px @theme_bg_color;
    color: @theme_text_color;
}
.textHeaderBar{
    font-weight: bold;
}
.menu:hover {	
  border-color:alpha(@theme_text_color, 0.01);
}

.menu:hover >* {
border-color:alpha(@theme_text_color, 0.01);
}

.menuitemtop{
margin-bottom:0px;
}
.menuitemtop *{
margin:2px 2px 0 2px;
padding: 5px 10px 3px 5px;
}
.menuitemmiddle *{
margin:0 2px 0 2px;
padding: 3px 10px 3px 5px;
}
.menuitembottom *{
margin:0 2px 2px 2px;
padding: 3px 10px 5px 5px;
}
.menuitemtop:hover {
background:@theme_bg_color;
border-color:inherit;
border-left-width:inherit;
border-right-width:inherit;
}
.menuitemmiddle:hover {
background:@theme_bg_color;
border-color:inherit;
border-left-width:inherit;
border-right-width:inherit;
}
.menuitembottom:hover {
background:@theme_bg_color;
border-color:inherit;
border-left-width:inherit;
border-right-width:inherit;

}
.menuitemtop:hover* {
margin:2px 2px 0 2px;
padding: 5px 10px 3px 5px;
background:@theme_selected_bg_color;
border-radius:2px;
}
.menuitemmiddle:hover* {
margin:0 2px 0 2px;
padding: 3px 10px 3px 5px;
background:@theme_selected_bg_color;
border-radius:2px;
}
.menuitembottom:hover* {
margin:0 2px 2px 2px;
padding: 3px 10px 5px 5px;
background:@theme_selected_bg_color;
border-radius:2px;
}

.noborder{
  border:none;
}

.bkim{
  opacity:0.99;
  border:none;
}

.bkim_no_plug{
  background-color: transparent;
  opacity:0.99;
}

.entry {

}
.entry:focus {

}